Module audio

Module audio 

Audio server and device detection.

Functions

detect_audio
Detects the active audio server and hardware sound cards.
normalize_win_audio_device
Filter out synthetic software proxy audio drivers and normalize root hardware controller names on Windows.
parse_asound_cards