Active media player and currently playing track detection.
Provides 100% native detection without forking child processes:
- Linux: Direct Unix domain socket connection to
$DBUS_SESSION_BUS_ADDRESS//run/user/<uid>/busspeaking the binary D-Bus wire protocol for MPRIS (org.mpris.MediaPlayer2.*). - Windows: Native WinRT COM FFI via
combase.dllqueryingWindows.Media.Control.GlobalSystemMediaTransportControlsSessionManager. - macOS: Native Objective-C runtime FFI via
macos_ffi.rsquerying running media apps.
Modules
Structs
- Media
Info - Information about the active media player and currently playing track.
Functions
- detect_
media - Detects the active media player and currently playing track.
- detect_
media_ info - Detects raw
MediaInfofrom the platform’s native media subsystem.